summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorNick Burch <nick@apache.org>2015-03-13 17:17:27 +0000
committerNick Burch <nick@apache.org>2015-03-13 17:17:27 +0000
commitf5d6985737e408275e4c145fd35fc9a0ee431a0d (patch)
treed6a453b50112da0a52452f6317e486ba97a799e8 /src
parent06efaaecf8b5d89a7b2e7823098c6110a7b3f989 (diff)
downloadpoi-f5d6985737e408275e4c145fd35fc9a0ee431a0d.tar.gz
poi-f5d6985737e408275e4c145fd35fc9a0ee431a0d.zip
More relation types
git-svn-id: https://svn.apache.org/repos/asf/poi/trunk@1666517 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src')
-rw-r--r--src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java21
1 files changed, 16 insertions, 5 deletions
diff --git a/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java b/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java
index 134e6a9fa3..bee45e5366 100644
--- a/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java
+++ b/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java
@@ -19,12 +19,8 @@ package org.apache.poi.openxml4j.opc;
/**
* Relationship types.
- *
- * @author Julien Chable
- * @version 0.2
*/
public interface PackageRelationshipTypes {
-
/**
* Core properties relationship type.
*
@@ -70,16 +66,26 @@ public interface PackageRelationshipTypes {
*/
String EXTENDED_PROPERTIES = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties";
+ /**
+ * Extended properties relationship type for strict ooxml.
+ */
+ String STRICT_EXTENDED_PROPERTIES = "http://purl.oclc.org/ooxml/officeDocument/relationships/extendedProperties";
+
/**
* Custom properties relationship type.
*/
String CUSTOM_PROPERTIES = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/custom-properties";
/**
* Core properties relationship type.
*/
String CORE_DOCUMENT = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
+ /**
+ * Core document relationship type for strict ooxml.
+ */
+ String STRICT_CORE_DOCUMENT = "http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument";
+
/**
* Custom XML relationship type.
*/
@@ -104,4 +110,9 @@ public interface PackageRelationshipTypes {
* External Link to another Document
*/
String EXTERNAL_LINK_PATH = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLinkPath";
+
+ /**
+ * Visio 2010 VSDX equivalent of package {@link #CORE_DOCUMENT}
+ */
+ String VISIO_CORE_DOCUMENT = "http://schemas.microsoft.com/visio/2010/relationships/document";
}
@@ -70,16 +66,26 @@ public interface PackageRelationshipTypes {
String CUSTOM_PROPERTIES = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/custom-properties";
/**
- * Core properties relationship type.
+ * Core document relationship type.
*/
String CORE_DOCUMENT = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";